@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
 from collections import namedtuple
 
+__version__ = '0.18.0'
+
 App = namedtuple('App', ['instance', 'base_url', 'client_id', 'client_secret'])
 User = namedtuple('User', ['instance', 'username', 'access_token'])
 
@@ -11,7 +11,3 @@ DEFAULT_INSTANCE = 'mastodon.social'
 
 CLIENT_NAME = 'toot - a Mastodon CLI client'
 CLIENT_WEBSITE = 'https://github.com/ihabunek/toot'
-
-
-class ConsoleError(Exception):
-    pass
