@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-from __future__ import print_function
 
 import os
 import sys
@@ -8,10 +6,10 @@ import logging
 
 from argparse import ArgumentParser, FileType
 from collections import namedtuple
-from toot import config, api, commands, ConsoleError, CLIENT_NAME, CLIENT_WEBSITE
+from toot import config, commands, CLIENT_NAME, CLIENT_WEBSITE, __version__
+from toot.exceptions import ApiError, ConsoleError
 from toot.output import print_out, print_err
 
-
 VISIBILITY_CHOICES = ['public', 'unlisted', 'private', 'direct']
 
 
@@ -40,7 +38,7 @@ common_args = [
 ]
 
 account_arg = (["account"], {
-    "help": "account name, e.g. 'Gargron' or 'polymerwitch@toot.cat'",
+    "help": "account name, e.g. 'Gargron@mastodon.social'",
 })
 
 instance_arg = (["-i", "--instance"], {
@@ -57,31 +55,31 @@ email_arg = (["-e", "--email"], {
 AUTH_COMMANDS = [
     Command(
         name="login",
-        description="Log into a Mastodon instance, does NOT support two factor authentication",
+        description="Log in from the console, does NOT support two factor authentication",
         arguments=[instance_arg, email_arg],
         require_auth=False,
     ),
     Command(
         name="login_browser",
         description="Log in using your browser, supports regular and two factor authentication",
-        arguments=[instance_arg, email_arg],
+        arguments=[instance_arg],
         require_auth=False,
     ),
     Command(
-        name="login_2fa",
-        description="Log in using two factor authentication in the console (hacky, experimental)",
-        arguments=[],
+        name="activate",
+        description="Switch between logged in accounts.",
+        arguments=[account_arg],
         require_auth=False,
     ),
     Command(
         name="logout",
         description="Log out, delete stored access keys",
-        arguments=[],
+        arguments=[account_arg],
         require_auth=False,
     ),
     Command(
         name="auth",
-        description="Show stored credentials",
+        description="Show logged in accounts and instances",
         arguments=[],
         require_auth=False,
     ),
@@ -104,6 +102,18 @@ READ_COMMANDS = [
         ],
         require_auth=True,
     ),
+    Command(
+        name="instance",
+        description="Display instance details",
+        arguments=[
+            (["instance"], {
+                "help": "instance domain (e.g. 'mastodon.social') or blank to use current",
+                "nargs": "?",
+            }),
+
+        ],
+        require_auth=False,
+    ),
     Command(
         name="search",
         description="Search for users or hashtags",
@@ -121,15 +131,44 @@ READ_COMMANDS = [
     ),
     Command(
         name="timeline",
-        description="Show recent items in your public timeline",
-        arguments=[],
+        description="Show recent items in a timeline (home by default)",
+        arguments=[
+            (["-p", "--public"], {
+                "action": "store_true",
+                "default": False,
+                "help": "Show public timeline.",
+            }),
+            (["-t", "--tag"], {
+                "type": str,
+                "help": "Show timeline for given hashtag.",
+            }),
+            (["-i", "--list"], {
+                "type": int,
+                "help": "Show timeline for given list ID.",
+            }),
+            (["-l", "--local"], {
+                "action": "store_true",
+                "default": False,
+                "help": "Show only statuses from local instance (public and tag timelines only).",
+            }),
+        ],
         require_auth=True,
     ),
     Command(
         name="curses",
         description="An experimental timeline app (doesn't work on Windows)",
-        arguments=[],
-        require_auth=True,
+        arguments=[
+            (["-p", "--public"], {
+                "action": 'store_true',
+                "default": False,
+                "help": "Resolve non-local accounts",
+            }),
+            (["-i", "--instance"], {
+                "type": str,
+                "help": 'instance from which to read (for public timeline only)',
+            })
+        ],
+        require_auth=False,
     ),
 ]
 
@@ -140,6 +179,7 @@ POST_COMMANDS = [
         arguments=[
             (["text"], {
                 "help": "The status text to post.",
+                "nargs": "?",
             }),
             (["-m", "--media"], {
                 "type": FileType('rb'),
@@ -149,6 +189,15 @@ POST_COMMANDS = [
                 "type": visibility,
                 "default": "public",
                 "help": 'post visibility, one of: %s' % ", ".join(VISIBILITY_CHOICES),
+            }),
+            (["-s", "--sensitive"], {
+                "action": 'store_true',
+                "default": False,
+                "help": "mark the media as NSFW",
+            }),
+            (["-p", "--spoiler-text"], {
+                "type": str,
+                "help": 'text to be shown as a warning before the actual content',
             })
         ],
         require_auth=True,
@@ -231,6 +280,7 @@ def print_usage():
     ]
 
     print_out("<green>{}</green>".format(CLIENT_NAME))
+    print_out("<blue>v{}</blue>".format(__version__))
 
     for name, cmds in groups:
         print_out("")
@@ -256,6 +306,10 @@ def get_argument_parser(name, command):
     for args, kwargs in command.arguments + common_args:
         parser.add_argument(*args, **kwargs)
 
+    # If the command requires auth, give an option to select account
+    if command.require_auth:
+        parser.add_argument("-u", "--using", help="the account to use, overrides active account")
+
     return parser
 
 
@@ -270,6 +324,12 @@ def run_command(app, user, name, args):
     parser = get_argument_parser(name, command)
     parsed_args = parser.parse_args(args)
 
+    # Override the active account if 'using' option is given
+    if command.require_auth and parsed_args.using:
+        user, app = config.get_user_app(parsed_args.using)
+        if not user or not app:
+            raise ConsoleError("User '{}' not found".format(parsed_args.using))
+
     if command.require_auth and (not user or not app):
         print_err("This command requires that you are logged in.")
         print_err("Please run `toot login` first.")
@@ -284,9 +344,10 @@ def run_command(app, user, name, args):
 
 
 def main():
-    # Enable debug log if --debug is in args
+    # Enable debug logging if --debug is in args
     if "--debug" in sys.argv:
-        logging.basicConfig(level=logging.DEBUG)
+        filename = os.getenv("TOOT_LOG_FILE")
+        logging.basicConfig(level=logging.DEBUG, filename=filename)
 
     # If something is piped in, append it to commandline arguments
     if not sys.stdin.isatty():
@@ -300,14 +361,13 @@ def main():
     if not command_name:
         return print_usage()
 
-    user = config.load_user()
-    app = config.load_app(user.instance) if user else None
+    user, app = config.get_active_user_app()
 
     try:
         run_command(app, user, command_name, args)
     except ConsoleError as e:
         print_err(str(e))
         sys.exit(1)
-    except api.ApiError as e:
+    except ApiError as e:
         print_err(str(e))
         sys.exit(1)
